@@ -18,11 +18,20 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
-package main;
-$main::VERSION = '0.04';
+
 use warnings;
 use strict;
 use Config;
+use Siebel::Srvrmgr::ListParser::Output::ListComp::Server 0.24;
+use Siebel::Srvrmgr::ListParser::Output::Tabular::ListParams 0.24;
+use Siebel::Srvrmgr::Daemon::Command 0.24;
+use Siebel::Srvrmgr::Exporter::ListCompDef;
+use Siebel::Srvrmgr::Exporter::ListComp;
+use Siebel::Srvrmgr::Exporter::ListCompTypes;
+use File::Spec;
+use Getopt::Std;
+use Siebel::Srvrmgr::Exporter;
+our $VERSION = '0.05'; # VERSION
 
 my $yap;
 
@@ -47,18 +56,15 @@ BEGIN {
 
     }
 
+    if ( $Config{osname} eq 'MSWin32' ) {
+        require Siebel::Srvrmgr::Daemon::Light;
+    }
+    else {
+        require Siebel::Srvrmgr::Daemon::Heavy;
+    }
+
 }
 
-use Siebel::Srvrmgr::Daemon::Heavy 0.21;
-use Siebel::Srvrmgr::ListParser::Output::ListComp::Server 0.21;
-use Siebel::Srvrmgr::ListParser::Output::Tabular::ListParams 0.21;
-use Siebel::Srvrmgr::Daemon::Command 0.21;
-use Siebel::Srvrmgr::Exporter::ListCompDef;
-use Siebel::Srvrmgr::Exporter::ListComp;
-use Siebel::Srvrmgr::Exporter::ListCompTypes;
-use File::Spec;
-use Getopt::Std;
-use Siebel::Srvrmgr::Exporter;
 
 $Getopt::Std::STANDARD_HELP_VERSION = 2;
 
@@ -74,7 +80,7 @@ sub HELP_MESSAGE {
 
     print <<BLOCK;
 
-export_comps - version $Siebel::Srvrmgr::Exporter::VERSION
+export_comps - version $VERSION
 
 This program will connect to a Siebel server and exports all components configuration in the form of "create component" commands.
 Those commands can be used with srvrmgr program to recreate those components in another Siebel server. Think of it something like a "Siebel component dumper".
@@ -163,8 +169,14 @@ if ( exists( $opts{d} ) ) {
 }
 
 $yap->start() unless ( $opts{q} );
+my $daemon;
 
-my $daemon = Siebel::Srvrmgr::Daemon::Heavy->new( \%daemon_options );
+if ( $Config{osname} eq 'MSWin32' ) {
+    $daemon = Siebel::Srvrmgr::Daemon::Light->new( \%daemon_options );
+}
+else {
+    $daemon = Siebel::Srvrmgr::Daemon::Heavy->new( \%daemon_options );
+}
 
 # these variables are global caches for component definitions and component types respectively
 my ( $DEFS_REF, $TYPES_REF );
