@@ -1,7 +1,8 @@
 package Siebel::Srvrmgr::Exporter;
-$Siebel::Srvrmgr::Exporter::VERSION = '0.04';
+
 use strict;
 use warnings;
+our $VERSION = '0.05'; # VERSION
 
 1;
 __END__
@@ -9,7 +10,7 @@ __END__
 
 Siebel::Srvrmgr::Exporter - Perl extension for dumping Siebel Components data
 
-head1 SYNOPSIS
+=head1 SYNOPSIS
 
   use Siebel::Srvrmgr::Exporter;
 
